@@ -1,7 +1,7 @@
 GetWorkerStatistic <-
 workerstatistic <-
 function (worker, statistic, period = "LifeToDate", count = NULL, 
-    response.group = NULL, verbose = getOption('MTurkR.verbose'), ...){
+    response.group = NULL, verbose = getOption('MTurkR.verbose', TRUE), ...){
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
