@@ -2,7 +2,7 @@ RegisterHITType <-
 hittype <-
 function (title, description, reward, duration, keywords = NULL, 
     auto.approval.delay = NULL, qual.req = NULL,
-    verbose = getOption('MTurkR.verbose'), ...){
+    verbose = getOption('MTurkR.verbose', TRUE), ...){
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
