@@ -1,7 +1,7 @@
 RejectAssignment <-
 RejectAssignments <-
 reject <-
-function (assignments, feedback = NULL, verbose = getOption('MTurkR.verbose'), ...){
+function (assignments, feedback = NULL, verbose = getOption('MTurkR.verbose', TRUE), ...){
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
