@@ -1,5 +1,5 @@
 WorkerReport <-
-function (worker, period = "LifeToDate", verbose = getOption('MTurkR.verbose'), ...){
+function (worker, period = "LifeToDate", verbose = getOption('MTurkR.verbose', TRUE), ...){
     if(is.na(pmatch(period,c("OneDay", "SevenDays", "ThirtyDays", "LifeToDate")))) 
         stop("Period not valid. Must be 'OneDay', 'SevenDays', 'ThirtyDays', or 'LifeToDate'.   ")
     statistics <- c("NumberAssignmentsApproved", "NumberAssignmentsRejected", 
